function showInline(eleId) {
    document.getElementById(eleId).style.display = "inline-block"
}

function hideEle(eleId) {
    document.getElementById(eleId).style.display = "none"
}

function raiseCanvas() {
    const lc = document.querySelector("#fabric-canvas-div .lower-canvas")
    lc.style["z-index"] = 98
    const uc = document.querySelector("#fabric-canvas-div .upper-canvas")
    uc.style["z-index"] = 99
}

function lowerCanvas() {
    const lc = document.querySelector("#fabric-canvas-div .lower-canvas")
    lc.style["z-index"] = -101
    const uc = document.querySelector("#fabric-canvas-div .upper-canvas")
    uc.style["z-index"] = -100
}

function showPanel() {
    showInline("fabric-controls")
    showInline("fabric-hide")
    hideEle("fabric-show")
    raiseCanvas()
}

function hidePanel() {
    hideEle("fabric-controls")
    hideEle("fabric-hide")
    showInline("fabric-show")
    lowerCanvas()
}


function slide_drawing_init(paneId) {
    const overpane = document.getElementById(paneId)
    overpane.innerHTML = `
        <div id="fabric-panel">
            <div class="fabric-subpanel" id="fabric-show-hide">
                <div class="fabric-button" id="fabric-show"> </div>
                <div class="fabric-button" id="fabric-hide"> </div>
            </div>
            <div class="fabric-subpanel" id="fabric-controls">
                <div class="fabric-button" id="fabric-sel"> </div>
                <div class="fabric-button" id="fabric-red"> </div>
                <div class="fabric-button" id="fabric-blue"> </div>
                <div class="fabric-button" id="fabric-black"> </div>
                <div class="fabric-button" id="fabric-delete"> </div>
                <div class="fabric-button" id="fabric-clear"> </div>
            </div>
        </div>
        <div id="fabric-canvas-div">
            <canvas id="fabric-canvas" width="2000" height="2000"></canvas>
        </div>
    `;

    const canvas = new fabric.Canvas("fabric-canvas");

    hidePanel()

    document.getElementById("fabric-show").onclick = showPanel
    document.getElementById("fabric-hide").onclick = function () {
        hidePanel()
        canvas.clear()
    }

    document.getElementById("fabric-sel").onclick = function () {
        canvas.isDrawingMode = false
    }

    function initBrush(col) {
        canvas.isDrawingMode = true
        canvas.freeDrawingBrush.color = col
        canvas.freeDrawingBrush.width = 3
    }

    new Array("red", "blue", "black").forEach(col => {
        document.getElementById("fabric-" + col).addEventListener("click", (e) => {
            initBrush(col);
        })
    })

    document.getElementById("fabric-delete").onclick = function () {
        canvas.getActiveObjects().forEach(o => {
            canvas.remove(o)
        });
    }

    document.getElementById("fabric-clear").onclick = function () {
        canvas.clear()
    }

    document.addEventListener('keydown', (e) => {
        switch (e.key) {
            case "ArrowLeft":
            case "ArrowRight":
            case "PageUp":
            case "PageDown":
            case " ":
            case "c":
                lowerCanvas();
                canvas.clear();
                break;

            case "r":
                raiseCanvas();
                initBrush("red");
                break;
        }
    });
}
